@@ -8,8 +8,8 @@ test_that("qPCR2fdata gives the correct dimensions and properties", {
   res_fdata_preprocess <- qPCR2fdata(testdat, preprocess = TRUE)
 
   expect_that(res_fdata, is_a("fdata"))
-  expect_that(length(res_fdata$rangeval) == 2 && res_fdata$rangeval[2] == 49, is_true())
+  expect_true(length(res_fdata$rangeval) == 2 && res_fdata$rangeval[2] == 49)
 
   expect_that(res_fdata_preprocess, is_a("fdata"))
-  expect_that(length(res_fdata_preprocess$rangeval) == 2 && res_fdata_preprocess$rangeval[2] == 49, is_true())
+  expect_true(length(res_fdata_preprocess$rangeval) == 2 && res_fdata_preprocess$rangeval[2] == 49)
 })
